package cn.minestar.agriculture.service.impl;

import java.util.ArrayList;
import java.util.List;

import cn.minestar.agriculture.entity.WxMiniMenu;
import cn.minestar.agriculture.mapper.WxMiniMenuMapper;
import cn.minestar.agriculture.service.IWxMiniMenuService;
import cn.minestar.agriculture.vo.WxMiniMenuVo;
import cn.minestar.common.utils.DateUtils;
import cn.minestar.weixin.utils.ThirdSessionHolder;
import org.modelmapper.ModelMapper;
import org.modelmapper.TypeToken;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author www.minestar.cn/
 * @date 2021-08-10
 */
@Service
public class WxMiniMenuServiceImpl implements IWxMiniMenuService
{
    @Autowired
    private WxMiniMenuMapper wxMiniMenuMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public WxMiniMenu selectWxMiniMenuById(Long id)
    {
        return wxMiniMenuMapper.selectWxMiniMenuById(id);
    }

    /**
     *
     * 
     * @param wxMiniMenu 获取用户菜单
     * @return
     */
    @Override
    public List<WxMiniMenuVo> selectWxMiniMenuTreeByUserId(WxMiniMenu wxMiniMenu)
    {
        String admin = ThirdSessionHolder.getThirdSession().getAdmin();   //是否管理员：（1：管理员，0：普通用户）
        List<WxMiniMenu> list = wxMiniMenuMapper.selectWxMiniMenuList(wxMiniMenu);
        ModelMapper modelMap = new ModelMapper();
        List<WxMiniMenuVo> menus = modelMap.map(list,new TypeToken<List<WxMiniMenuVo>>(){}.getType());
        return bulidMenuTree(menus,0);
    }

    private List<WxMiniMenuVo> bulidMenuTree(List<WxMiniMenuVo> menus, int parentId) {
        List<WxMiniMenuVo> list = new ArrayList<>();
        for(WxMiniMenuVo vo : menus){
            if(vo.getParentId().longValue() == parentId){
                list.add(vo);
                recursionFn(menus, vo);
            }
        }
        return list;
    }

    private void recursionFn(List<WxMiniMenuVo> menus, WxMiniMenuVo wxMiniMenuVo) {

        List<WxMiniMenuVo> children = getChildList(menus,wxMiniMenuVo);
        wxMiniMenuVo.setChildren(children);
        for(WxMiniMenuVo vo : children){
          if(hasChild(menus,vo)){
              recursionFn(menus,vo);
          }
        }

    }

    private boolean hasChild(List<WxMiniMenuVo> menus, WxMiniMenuVo vo) {
        return getChildList(menus,vo).size() > 0 ? true:false;
    }

    private List<WxMiniMenuVo> getChildList(List<WxMiniMenuVo> menus, WxMiniMenuVo wxMiniMenuVo) {
        List<WxMiniMenuVo> children = new ArrayList<>();
        for(WxMiniMenuVo vo: menus){

            if(vo.getParentId().longValue() == wxMiniMenuVo.getId().longValue()){
                children.add(vo);
            }
        }
        return children;
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniMenu 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertWxMiniMenu(WxMiniMenu wxMiniMenu)
    {
        wxMiniMenu.setCreateTime(DateUtils.getNowDate());
        return wxMiniMenuMapper.insertWxMiniMenu(wxMiniMenu);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniMenu 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateWxMiniMenu(WxMiniMenu wxMiniMenu)
    {
        wxMiniMenu.setUpdateTime(DateUtils.getNowDate());
        return wxMiniMenuMapper.updateWxMiniMenu(wxMiniMenu);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteWxMiniMenuByIds(Long[] ids)
    {
        return wxMiniMenuMapper.deleteWxMiniMenuByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteWxMiniMenuById(Long id)
    {
        return wxMiniMenuMapper.deleteWxMiniMenuById(id);
    }
}
